#!/usr/bin/env python3

# Copyright (C) 2023 IndiScale GmbH <www.indiscale.com>
# Copyright (C) 2023 Daniel Hornung <d.hornung@indiscale.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.

"""Create JSON-Schema according to configuration
"""

import argparse
import json
import os
import sys

import caosadvancedtools.json_schema_exporter as jsex
import caosadvancedtools.models.parser as parser
import tomli

# TODO why do I need a running LA instance?


def prepare_datamodel():
    model = parser.parse_model_from_yaml("./model.yml")

    exporter = jsex.JsonSchemaExporter(additional_properties=False,
                                       # additional_options_for_text_props=additional_text_options,
                                       # name_and_description_in_properties=True,
                                       name_property_for_new_records=True,
                                       do_not_create=["Organisation"],
                                       # do_not_retrieve=do_not_retrieve,
                                       )
    schema_top = exporter.recordtype_to_json_schema(model.get_deep("Training"))
    schema_pers = exporter.recordtype_to_json_schema(model.get_deep("Person"))
    merged_schema = jsex.merge_schemas([schema_top, schema_pers])

    with open("model_schema.json", mode="w", encoding="utf8") as json_file:
        json.dump(merged_schema, json_file, ensure_ascii=False, indent=2)


def _parse_arguments():
    """Parse the arguments."""
    parser = argparse.ArgumentParser(description='')

    return parser.parse_args()


def main():
    """The main function of this script."""
    args = _parse_arguments()
    prepare_datamodel()


if __name__ == "__main__":
    main()
